# ronak_Package_test
This is a simple Package to print a patterns

## Installation

Install it using pip:

pip install ronak_Package_test

from Patern import (pyramid, right_angle, left_angle)

# pyramid
pyramid(5)

# Output

    * 
   * * 
  * * *
 * * * *
* * * * *